aboutsummaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
-rw-r--r--src/CMakeLists.txt2
-rw-r--r--src/Core/Block.h10
-rw-r--r--src/Core/CMakeLists.txt2
-rw-r--r--src/Core/Column.h10
-rw-r--r--src/Core/Conjugate.h10
-rw-r--r--src/Core/CopyHelper.h10
-rw-r--r--src/Core/Dot.h10
-rw-r--r--src/Core/Eval.h10
-rw-r--r--src/Core/Fuzzy.h10
-rw-r--r--src/Core/Matrix.h10
-rw-r--r--src/Core/MatrixOps.h10
-rw-r--r--src/Core/MatrixRef.h10
-rw-r--r--src/Core/MatrixStorage.h10
-rw-r--r--src/Core/Minor.h10
-rw-r--r--src/Core/Numeric.h10
-rw-r--r--src/Core/Object.h10
-rw-r--r--src/Core/Random.h10
-rw-r--r--src/Core/Row.h10
-rw-r--r--src/Core/ScalarOps.h10
-rw-r--r--src/Core/Trace.h10
-rw-r--r--src/Core/Transpose.h10
-rw-r--r--src/Core/Util.h10
-rw-r--r--test/main.cpp12
-rw-r--r--test/main.h14
-rw-r--r--test/matrixmanip.cpp12
-rw-r--r--test/matrixops.cpp12
-rw-r--r--test/vectorops.cpp12
27 files changed, 133 insertions, 133 deletions
diff --git a/src/CMakeLists.txt b/src/CMakeLists.txt
index 78a05eec6..12b5da282 100644
--- a/src/CMakeLists.txt
+++ b/src/CMakeLists.txt
@@ -1,4 +1,4 @@
-FILE(GLOB gen_SRCS "*.h")
+FILE(GLOB Eigen_SRCS "*.h")
SET(INCLUDE_INSTALL_DIR
"${CMAKE_INSTALL_PREFIX}/include/eigen2"
diff --git a/src/Core/Block.h b/src/Core/Block.h
index 1ddd86540..a6dc51df1 100644
--- a/src/Core/Block.h
+++ b/src/Core/Block.h
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
diff --git a/src/Core/CMakeLists.txt b/src/Core/CMakeLists.txt
index f5a6743ce..0f3ec5d4c 100644
--- a/src/Core/CMakeLists.txt
+++ b/src/Core/CMakeLists.txt
@@ -1,4 +1,4 @@
-FILE(GLOB gen_Core_SRCS "*.h")
+FILE(GLOB Eigen_Core_SRCS "*.h")
INSTALL(FILES
${gen_Core_SRCS}
diff --git a/src/Core/Column.h b/src/Core/Column.h
index bc669261a..5b9107619 100644
--- a/src/Core/Column.h
+++ b/src/Core/Column.h
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
diff --git a/src/Core/Conjugate.h b/src/Core/Conjugate.h
index 6431558f4..541f47da7 100644
--- a/src/Core/Conjugate.h
+++ b/src/Core/Conjugate.h
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
diff --git a/src/Core/CopyHelper.h b/src/Core/CopyHelper.h
index 4bb6c31c7..8b15aef8c 100644
--- a/src/Core/CopyHelper.h
+++ b/src/Core/CopyHelper.h
@@ -1,20 +1,20 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2007 Michael Olbrich <michael.olbrich@gmx.net>
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
diff --git a/src/Core/Dot.h b/src/Core/Dot.h
index 98adf3853..88b180c4c 100644
--- a/src/Core/Dot.h
+++ b/src/Core/Dot.h
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
diff --git a/src/Core/Eval.h b/src/Core/Eval.h
index 5551d8e21..3dd22bf9f 100644
--- a/src/Core/Eval.h
+++ b/src/Core/Eval.h
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
diff --git a/src/Core/Fuzzy.h b/src/Core/Fuzzy.h
index 8730a073b..eadffcff7 100644
--- a/src/Core/Fuzzy.h
+++ b/src/Core/Fuzzy.h
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
diff --git a/src/Core/Matrix.h b/src/Core/Matrix.h
index 3f57e2191..5717905b1 100644
--- a/src/Core/Matrix.h
+++ b/src/Core/Matrix.h
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
diff --git a/src/Core/MatrixOps.h b/src/Core/MatrixOps.h
index 0861a2bff..a1a1f47a0 100644
--- a/src/Core/MatrixOps.h
+++ b/src/Core/MatrixOps.h
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
diff --git a/src/Core/MatrixRef.h b/src/Core/MatrixRef.h
index d3fdae581..7e6aea5e6 100644
--- a/src/Core/MatrixRef.h
+++ b/src/Core/MatrixRef.h
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
diff --git a/src/Core/MatrixStorage.h b/src/Core/MatrixStorage.h
index 1fbc96ebc..5d636dc21 100644
--- a/src/Core/MatrixStorage.h
+++ b/src/Core/MatrixStorage.h
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
diff --git a/src/Core/Minor.h b/src/Core/Minor.h
index 11ca541bc..30bba17cc 100644
--- a/src/Core/Minor.h
+++ b/src/Core/Minor.h
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
diff --git a/src/Core/Numeric.h b/src/Core/Numeric.h
index 264c7a549..1bd48044b 100644
--- a/src/Core/Numeric.h
+++ b/src/Core/Numeric.h
@@ -1,20 +1,20 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
diff --git a/src/Core/Object.h b/src/Core/Object.h
index f8d1cb174..27e5e456a 100644
--- a/src/Core/Object.h
+++ b/src/Core/Object.h
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
diff --git a/src/Core/Random.h b/src/Core/Random.h
index ff3f8b418..9827f5585 100644
--- a/src/Core/Random.h
+++ b/src/Core/Random.h
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
diff --git a/src/Core/Row.h b/src/Core/Row.h
index 1fe1cf7ca..102890438 100644
--- a/src/Core/Row.h
+++ b/src/Core/Row.h
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
diff --git a/src/Core/ScalarOps.h b/src/Core/ScalarOps.h
index dc0709687..4a71b403e 100644
--- a/src/Core/ScalarOps.h
+++ b/src/Core/ScalarOps.h
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
diff --git a/src/Core/Trace.h b/src/Core/Trace.h
index 41394cffa..5ea999dae 100644
--- a/src/Core/Trace.h
+++ b/src/Core/Trace.h
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
diff --git a/src/Core/Transpose.h b/src/Core/Transpose.h
index 81f1090dd..2bc8c7575 100644
--- a/src/Core/Transpose.h
+++ b/src/Core/Transpose.h
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
diff --git a/src/Core/Util.h b/src/Core/Util.h
index 6871758c2..54edeed50 100644
--- a/src/Core/Util.h
+++ b/src/Core/Util.h
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
diff --git a/test/main.cpp b/test/main.cpp
index fa0348002..8610cf363 100644
--- a/test/main.cpp
+++ b/test/main.cpp
@@ -1,19 +1,19 @@
// This file is part of gen, a lightweight C++ template library
// for linear algebra. gen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
// gen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
// gen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
// with gen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
@@ -33,5 +33,5 @@ genTest::genTest()
srand(t);
}
-QTEST_APPLESS_MAIN( genTest )
+QTEST_APPLESS_MAIN( EigenTest )
#include "main.moc"
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
@@ -1,19 +1,19 @@
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
@@ -1,19 +1,19 @@
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
@@ -1,19 +1,19 @@
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
diff --git a/test/main.h b/test/main.h
index c5aa3c085..47ea1b928 100644
--- a/test/main.h
+++ b/test/main.h
@@ -1,19 +1,19 @@
// This file is part of gen, a lightweight C++ template library
// for linear algebra. gen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
// gen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
// gen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
// with gen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
@@ -36,12 +36,12 @@ USING_EIGEN_DATA_TYPES
using namespace std;
-class genTest : public QObject
+class EigenTest : public QObject
{
Q_OBJECT
public:
- genTest();
+ EigenTest();
private slots:
void testVectorOps();
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
@@ -1,19 +1,19 @@
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
@@ -1,19 +1,19 @@
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
@@ -1,19 +1,19 @@
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
diff --git a/test/matrixmanip.cpp b/test/matrixmanip.cpp
index c8863d183..eba184179 100644
--- a/test/matrixmanip.cpp
+++ b/test/matrixmanip.cpp
@@ -1,19 +1,19 @@
// This file is part of gen, a lightweight C++ template library
// for linear algebra. gen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
// gen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
// gen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
// with gen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
@@ -42,7 +42,7 @@ template<typename MatrixType> void matrixManip(const MatrixType& m)
a.minor(i, j) -= a.block(1, rows-1, 1, cols-1).eval();
}
-void genTest::testMatrixManip()
+void EigenTest::testMatrixManip()
{
matrixManip(Matrix<int, 2, 3>());
matrixManip(Matrix<double, 3, 3>());
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
@@ -1,19 +1,19 @@
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
@@ -1,19 +1,19 @@
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
@@ -1,19 +1,19 @@
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
diff --git a/test/matrixops.cpp b/test/matrixops.cpp
index 100dbeffb..c763ff687 100644
--- a/test/matrixops.cpp
+++ b/test/matrixops.cpp
@@ -1,19 +1,19 @@
// This file is part of gen, a lightweight C++ template library
// for linear algebra. gen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
// gen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
// gen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
// with gen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
@@ -59,7 +59,7 @@ template<typename MatrixType1,
QVERIFY( (d * e).rows() == rows1 && (d * e).cols() == cols2 );
}
-void genTest::testMatrixOps()
+void EigenTest::testMatrixOps()
{
matrixOps(Matrix<float, 1, 1>(), Matrix<float, 1, 1>());
matrixOps(Matrix<int, 2, 3>(), Matrix<int, 3, 1>());
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
@@ -1,19 +1,19 @@
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
@@ -1,19 +1,19 @@
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
@@ -1,19 +1,19 @@
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
diff --git a/test/vectorops.cpp b/test/vectorops.cpp
index 87195ac36..77a01fbcd 100644
--- a/test/vectorops.cpp
+++ b/test/vectorops.cpp
@@ -1,19 +1,19 @@
// This file is part of gen, a lightweight C++ template library
// for linear algebra. gen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
// gen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
// gen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
// with gen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
@@ -50,7 +50,7 @@ template<typename VectorType> void vectorOps(const VectorType& v)
a += (a + a).eval();
}
-void genTest::testVectorOps()
+void EigenTest::testVectorOps()
{
vectorOps(Vector2i());
vectorOps(Vector3d());
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
@@ -1,19 +1,19 @@
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
@@ -1,19 +1,19 @@
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
@@ -1,19 +1,19 @@
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//